@@ -83,11 +83,13 @@
 --     * Slot: datatype Description: 
 --     * Slot: language Description: 
 -- # Class: "owl_axiom_annotation" Description: ""
---     * Slot: axiom_predicate Description: 
---     * Slot: axiom_object Description: 
---     * Slot: axiom_value Description: 
---     * Slot: axiom_language Description: 
---     * Slot: axiom_datatype Description: 
+--     * Slot: annotation_subject Description: 
+--     * Slot: annotation_predicate Description: 
+--     * Slot: annotation_object Description: 
+--     * Slot: annotation_value Description: 
+--     * Slot: annotation_language Description: 
+--     * Slot: annotation_datatype Description: 
+--     * Slot: id Description: An identifier for an element. Note blank node ids are not unique across databases
 --     * Slot: stanza Description: 
 --     * Slot: subject Description: 
 --     * Slot: predicate Description: 
@@ -124,6 +126,9 @@
 --     * Slot: filler Description: This is Null for a self-restriction
 --     * Slot: id Description: An identifier for an element. Note blank node ids are not unique across databases
 -- # Class: "owl_complex_axiom" Description: "An axiom that is composed of two or more statements"
+--     * Slot: subject Description: 
+--     * Slot: predicate Description: 
+--     * Slot: object Description: Note the range of this slot is always a node. If the triple represents a literal, instead value will be populated
 -- # Class: "owl_subclass_of_some_values_from" Description: "Composition of subClassOf and SomeValuesFrom"
 --     * Slot: subject Description: the class C in the axiom C subClassOf P some D
 --     * Slot: predicate Description: the predicate P in the axiom C subClassOf P some D
@@ -131,6 +136,7 @@
 -- # Class: "owl_equivalent_to_intersection_member" Description: "Composition of `OwlEquivalentClass`, `OwlIntersectionOf`, and `RdfListMember`; `C = X1 and ... and Xn`"
 --     * Slot: subject Description: the defined class
 --     * Slot: object Description: a class expression that forms the defining expression
+--     * Slot: predicate Description: 
 -- # Class: "prefix" Description: "Maps CURIEs to URIs"
 --     * Slot: prefix Description: A standardized prefix such as 'GO' or 'rdf' or 'FlyBase'
 --     * Slot: base Description: The base URI a prefix will expand to
@@ -399,18 +405,21 @@ CREATE TABLE owl_axiom (
 	PRIMARY KEY (id)
 );
 CREATE TABLE owl_axiom_annotation (
-	axiom_predicate TEXT, 
-	axiom_object TEXT, 
-	axiom_value TEXT, 
-	axiom_language TEXT, 
-	axiom_datatype TEXT, 
+	annotation_subject TEXT, 
+	annotation_predicate TEXT, 
+	annotation_object TEXT, 
+	annotation_value TEXT, 
+	annotation_language TEXT, 
+	annotation_datatype TEXT, 
+	id TEXT, 
 	stanza TEXT, 
 	subject TEXT, 
 	predicate TEXT, 
 	object TEXT, 
 	value TEXT, 
 	datatype TEXT, 
-	language TEXT
+	language TEXT, 
+	PRIMARY KEY (id)
 );
 CREATE TABLE anonymous_expression (
 	id TEXT, 
@@ -458,6 +467,11 @@ CREATE TABLE owl_has_self (
 	id TEXT, 
 	PRIMARY KEY (id)
 );
+CREATE TABLE owl_complex_axiom (
+	subject TEXT, 
+	predicate TEXT, 
+	object TEXT
+);
 CREATE TABLE owl_subclass_of_some_values_from (
 	subject TEXT, 
 	predicate TEXT, 
@@ -465,7 +479,8 @@ CREATE TABLE owl_subclass_of_some_values_from (
 );
 CREATE TABLE owl_equivalent_to_intersection_member (
 	subject TEXT, 
-	object TEXT
+	object TEXT, 
+	predicate TEXT
 );
 CREATE TABLE prefix (
 	prefix TEXT, 
@@ -650,8 +665,6 @@ CREATE TABLE count_of_subclasses (
 	element TEXT, 
 	count_value INTEGER
 );
--- ** REWRITE TABLES AS VIEWS **
--- SCHEMA: https://w3id.org/semsql/owl
 
 DROP TABLE ontology_node;
 CREATE VIEW ontology_node AS SELECT DISTINCT subject AS id FROM rdf_type_statement WHERE object='owl:Ontology';
@@ -675,7 +688,7 @@ DROP TABLE asymmetric_property_node;
 CREATE VIEW asymmetric_property_node AS SELECT DISTINCT subject AS id FROM rdf_type_statement WHERE object='owl:AsymmetricProperty';
 
 DROP TABLE annotation_property_node;
-CREATE VIEW annotation_property_node AS SELECT DISTINCT subject AS id FROM rdf_type_statement WHERE object='owl:AnnotatonProperty';
+CREATE VIEW annotation_property_node AS SELECT DISTINCT subject AS id FROM rdf_type_statement WHERE object='owl:AnnotationProperty';
 
 DROP TABLE deprecated_node;
 CREATE VIEW deprecated_node AS SELECT DISTINCT subject AS id FROM statements WHERE predicate='owl:deprecated' AND value='true';
@@ -705,7 +718,33 @@ DROP TABLE owl_axiom;
 CREATE VIEW owl_axiom AS SELECT * FROM owl_reified_axiom UNION SELECT NULL AS id, * FROM statements;
 
 DROP TABLE owl_axiom_annotation;
-CREATE VIEW owl_axiom_annotation AS SELECT axpv.stanza AS stanza, axs.object AS subject, axp.object AS predicate, axo.object AS object, axo.value AS value, axo.datatype AS datatype, axo.language AS language, axpv.subject AS id, axpv.predicate AS annotation_predicate, axpv.object AS annotation_iri, axpv.value AS annotation_value, axpv.language AS annotation_language, axpv.datatype AS annotation_datatype FROM statements AS axs, statements AS axp, statements AS axo, statements AS axpv WHERE axs.predicate = 'owl:annotatedSource' AND axp.predicate = 'owl:annotatedProperty' AND axo.predicate = 'owl:annotatedTarget' AND axs.subject = axpv.subject AND axp.subject = axpv.subject AND axo.subject = axpv.subject AND axpv.predicate NOT IN ('owl:annotatedSource', 'owl:annotatedProperty', 'owl:annotatedTarget', 'rdf:type');
+CREATE VIEW owl_axiom_annotation AS SELECT
+   axpv.stanza AS stanza,
+   axs.object AS subject,
+   axp.object AS predicate,
+   axo.object AS object,
+   axo.value AS value,
+   axo.datatype AS datatype,
+   axo.language AS language,
+   axpv.subject AS id,
+   axpv.subject AS annotation_subject,
+   axpv.predicate AS annotation_predicate,
+   axpv.object AS annotation_object,
+   axpv.value AS annotation_value,
+   axpv.language AS annotation_language,
+   axpv.datatype AS annotation_datatype
+  FROM
+   statements AS axs,
+   statements AS axp,
+   statements AS axo,
+   statements AS axpv
+  WHERE
+   axs.predicate = 'owl:annotatedSource' AND
+   axp.predicate = 'owl:annotatedProperty' AND
+   axo.predicate = 'owl:annotatedTarget' AND
+   axs.subject = axpv.subject AND
+   axp.subject = axpv.subject AND axo.subject = axpv.subject AND
+   axpv.predicate NOT IN ('owl:annotatedSource', 'owl:annotatedProperty', 'owl:annotatedTarget', 'rdf:type');
 
 DROP TABLE owl_some_values_from;
 CREATE VIEW owl_some_values_from AS SELECT onProperty.subject AS id,
